@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press::Keywords;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.028';
+our $VERSION   = '0.029';
 
 use Type::Library -base;
 use Type::Utils ();
@@ -41,10 +41,6 @@ sub confess {
 
 $EXPORT_TAGS{ 'util' } = [qw/ blessed confess /];
 
-use Try::Tiny;
-
-$EXPORT_TAGS{ 'try' } = [qw/ try catch finally /];
-
 push @EXPORT_OK, map @{$EXPORT_TAGS{$_}}, keys(%EXPORT_TAGS);
 
 my $orig = 'Type::Library'->can('import');
@@ -130,10 +126,6 @@ C<blessed> from L<Scalar::Util>.
 
 C<confess> from L<Carp>.
 
-=item *
-
-L<Try::Tiny>.
-
 =back
 
 You don't need to use it, but it might save a few lines of boilerplate
